# libmsec documentation for python.

import gettext

# localization
try:
    gettext.install('msec')
except IOError:
    _ = str

HELP = {


    'MAIL_WARN': _("Send security check results by email."), 

    'ENABLE_MSEC_CRON': _("Perform hourly security check for changes in system configuration."), 

    'ALLOW_SUDO_TO_WHEEL': _("Allow users in wheel group to use sudo. If this option is set to 'yes', the users in wheel group are allowed to use sudo and run commands as root by using their passwords. If this option to set to 'without-password', the users can use sudo without being asked for their password. WARNING: using sudo without any password makes your system very vulnerable, and you should only use this setting if you know what you are doing!"), 

    'CREATE_SERVER_LINK': _("Creates the symlink /etc/security/msec/server to point to /etc/security/msec/server.SERVER_LEVEL. The /etc/security/msec/server is used by chkconfig --add to decide to add a service if it is present in the file during the installation of packages. By default, two presets are provided: local (which only enables local services) and remote (which also enables some remote services considered safe). Note that the allowed services must be placed manually into the server.SERVER_LEVEL files when necessary."), 

    'CHECK_SECTOOL_LEVEL': _("Defines the sectool level to use during the periodic security check. You may use the sectool-gui application to select individual tests for each level. If this variable is not defined, the default level defined in sectool configuration will be used."), 

    'CHECK_RPM_INTEGRITY': _("Enable verification of integrity of installed RPM packages. This will notify you if checksums of the installed files were changed, showing separate results for binary and configuration files."), 

    'CHECK_SUID_ROOT': _("Enable checking for additions/removals of suid root files."), 

    'CHECK_GROUPS': _("Enable checking for changes in system groups."), 

    'IGNORE_PID_CHANGES': _("Ignore changes in process IDs when checking for open network ports."), 

    'CHECK_SUID_MD5': _("Enable checksum verification for suid files."), 

    'ENABLE_LOG_STRANGE_PACKETS': _("Enable logging of strange network packets."), 

    'MAIL_USER': _("User email to receive security notifications."), 

    'CHECK_USERS': _("Enable checking for changes in system users."), 

    'ACCEPT_BROADCASTED_ICMP_ECHO': _("Accept broadcasted ICMP echo."), 

    'ACCEPT_ICMP_ECHO': _("Accept ICMP echo."), 

    'ENABLE_STARTUP_PERMS': _("Enforce MSEC file directory permissions on system startup. If this parameter is set to 'enforce', system permissions will be enforced automatically, according to system security settings."), 

    'TTY_WARN': _("Enable periodic security check results to terminal."), 

    'CHECK_SECTOOL': _("Enable sectools checks. This check will run all sectool checks for a security level configuration. The security level to be used during this test is determined by the CHECK_SECTOOL_LEVELS variable."), 

    'FIX_UNOWNED': _("Fix owner and group of unowned files to use nobody/nogroup."), 

    'ENABLE_STARTUP_MSEC': _("Enforce MSEC settings on system startup"), 

    'ALLOW_X_CONNECTIONS': _("Allow local users to connect to X server. Accepted arguments: yes (all connections are allowed), local (only local connection), no (no connection)."), 

    'SECURE_TMP': _("Use secure location for temporary files. If this parameter is set to 'yes', user home directory will be used for temporary files. Otherwise, /tmp will be used."), 

    'ALLOW_REMOTE_ROOT_LOGIN': _("Allow remote root login via sshd. If yes, login is allowed. If without-password, only public-key authentication logins are allowed. See sshd_config(5) man page for more information."), 

    'CHECK_SHADOW': _("Enable checking for empty passwords in /etc/shadow (man shadow(5))."), 

    'ENABLE_AT_CRONTAB': _("Enable crontab and at for users. Put allowed users in /etc/cron.allow and /etc/at.allow (see man at(1) and crontab(1))."), 

    'ENABLE_PAM_WHEEL_FOR_SU': _("Allow only users in wheel group to su to root."), 

    'CHECK_SGID': _("Enable checking for additions/removals of sgid files."), 

    'CHECK_PASSWD': _("Enable password-related checks, such as empty passwords and strange super-user accounts."), 

    'CHECK_PERMS': _("Enable periodic permission checking for files specified in msec policy."), 

    'CHECK_PROMISC': _("Activate ethernet cards promiscuity check."), 

    'CHECK_PERMS_ENFORCE': _("Enable msec to enforce file permissions to the values specified in the msec security policy."), 

    'ALLOW_USER_LIST': _("Allow display managers (sddm and gdm) to display list of local users."), 

    'CHECK_OPEN_PORT': _("Enable checking for open network ports."), 

    'BASE_LEVEL': _("Defines the base security level, on top of which the current configuration is based."), 

    'PASSWORD_HISTORY': _("Set the password history length to prevent password reuse. This is not supported by pam_tcb."), 

    'CHECK_CHKROOTKIT': _("Enable checking for known rootkits using chkrootkit."), 

    'CHECK_UNOWNED': _("Enable checking for unowned files."), 

    'CHECK_FIREWALL': _("Enable checking for changes in firewall settings."), 

    'ROOT_UMASK': _("Set the root umask."), 

    'MAIL_EMPTY_CONTENT': _("Send mail reports even if no changes were detected."), 

    'ALLOW_REBOOT': _("Allow system reboot and shutdown to local users."), 

    'ALLOW_XSERVER_TO_LISTEN': _("Allow X server to accept connections from network on tcp port 6000."), 

    'CHECK_WRITABLE': _("Enable checking for files/directories writable by everybody."), 

    'ALLOW_AUTOLOGIN': _("Allow autologin."), 

    'SHELL_HISTORY_SIZE': _("Set shell commands history size. A value of -1 means unlimited."), 

    'ENABLE_CONSOLE_LOG': _("Log journal messages on console terminal 12."), 

    'LOG_RETENTION': _("Define the default retention period for logs, in weeks. Some countries require that the log files should be kept for 12 months, other do not have such strict requirements. This variable defines the number of past log files that should be kept by logrotate on the system."), 

    'ALLOW_CURDIR_IN_PATH': _("Include current directory into user PATH by default"), 

    'ACCEPT_BOGUS_ERROR_RESPONSES': _("Accept bogus IPv4 error messages."), 

    'NOTIFY_WARN': _("Show security notifications in system tray using libnotify."), 

    'CHECK_USER_FILES': _("Enable permission checking on users' files that should not be owned by someone else, or writable."), 

    'ENABLE_SULOGIN': _("Ask for root password when going to single user level (man sulogin(8))."), 

    'PASSWORD_LENGTH': _("Set the password minimum length and minimum number of digit and minimum number of capitalized letters, using length,ndigits,nupper format."), 

    'ENABLE_PASSWORD': _("Use password to authenticate users. Take EXTREME care when disabling passwords, as it will leave the machine vulnerable."), 

    'EXCLUDE_REGEXP': _("Patterns to exclude from disk checks. This parameter is parsed as a regex (7), so you may use complex expressions."), 

    'USER_UMASK': _("Set the user umask."), 

    'ENABLE_PAM_ROOT_FROM_WHEEL': _("Allow root access without password for the members of the wheel group."), 

    'AUTHORIZE_SERVICES': _("Allow full access to network services controlled by tcp_wrapper (see hosts.deny(5)). If yes, all services are allowed. If local, only connections to local services are authorized. If no, the services must be authorized manually in /etc/hosts.allow (see hosts.allow(5))."), 

    'WIN_PARTS_UMASK': _("Set umask option for mounting vfat and ntfs partitions. If umask is '-1', default system umask is used."), 

    'SHELL_TIMEOUT': _("Set the shell timeout. A value of zero means no timeout."), 

    'CHECK_SECURITY': _("Enable daily security checks."), 

    'ALLOW_ROOT_LOGIN': _("Allow direct root login on terminal."), 

    'CHECK_SHOSTS': _("Enable checking for dangerous options in users' .rhosts/.shosts files."), 

    'SYSLOG_WARN': _("Enables logging of periodic checks to system log."), 

    'CHECK_ON_BATTERY': _("Run security checks when machine is running on battery power."), 

    'CHECK_RPM_PACKAGES': _("Enable verification for changes in the installed RPM packages. This will notify you when new packages are installed or removed."), 

    'ENABLE_IP_SPOOFING_PROTECTION': _("Enable IP spoofing protection."), 

    'ALLOW_XAUTH_FROM_ROOT': _("Allow to export display when passing from the root account to the other users. See pam_xauth(8) for more details."), 
}

